<?php
/**
 * Main plugin file.
 * Finally, use widgets to customize your Footer area (a.k.a 'Return to Top' plus 'Copyright/Credits') in Genesis Framework and Child Themes.
 *
 * @package   Genesis Widgetized Footer
 * @author    David Decker
 * @link      http://twitter.com/deckerweb
 * @copyright Copyright 2012, David Decker - DECKERWEB
 *
 * Plugin Name: Genesis Widgetized Footer
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/genesis-widgetized-footer/
 * Description: Finally, use widgets to customize your Footer area (a.k.a 'Return to Top' plus 'Copyright/Credits') in Genesis Framework and Child Themes.
 * Version: 1.2
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPLv2
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 * Text Domain: genesis-widgetized-footer
 * Domain Path: /languages/
 *
 * Copyright 2012 David Decker - DECKERWEB
 *
 *     This file is part of Genesis Widgetized Footer,
 *     a plugin for WordPress.
 *
 *     Genesis Widgetized Footer is free software:
 *     You can redistribute it and/or modify it under the terms of the
 *     GNU General Public License as published by the Free Software
 *     Foundation, either version 2 of the License, or (at your option)
 *     any later version.
 *
 *     Genesis Widgetized Footer is distributed in the hope that
 *     it will be useful, but WITHOUT ANY WARRANTY; without even the
 *     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *     PURPOSE. See the GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with WordPress. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Setting constants
 *
 * @since 1.0
 * @version 1.1
 */
/** Set plugin version */
define( 'GWFOOT_VERSION', '1.2' );

/** Plugin directory */
define( 'GWFOOT_PLUGIN_DIR', dirname( __FILE__ ) );

/** Plugin base directory */
define( 'GWFOOT_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


add_action( 'init', 'ddw_gwfoot_init', 1 );
/**
 * Load the text domain for translation of the plugin
 * 
 * @since 1.0
 */
function ddw_gwfoot_init() {

	/** First look in WordPress' "languages" folder = custom & update-secure! */
	load_plugin_textdomain( 'genesis-widgetized-footer', false, GWFOOT_PLUGIN_BASEDIR . '/../../languages/genesis-widgetized-footer/' );

	/** Then look in plugin's "languages" folder = default */
	load_plugin_textdomain( 'genesis-widgetized-footer', false, GWFOOT_PLUGIN_BASEDIR . '/languages/' );

}  // end of function ddw_gwfoot_init


register_activation_hook( __FILE__, 'ddw_gwfoot_activation_check' );
/**
 * Checks for activated Genesis Framework before allowing plugin to activate
 *
 * @since 1.0
 */
function ddw_gwfoot_activation_check() {

	/**
	 * Look for translations to display for the activation message
	 * Look first in WordPress "languages" folder, then in plugin's "languages" folder
	 */
	load_plugin_textdomain( 'genesis-widgetized-footer', false, GWFOOT_PLUGIN_BASEDIR . '/../../languages/genesis-widgetized-footer/' );
	load_plugin_textdomain( 'genesis-widgetized-footer', false, GWFOOT_PLUGIN_BASEDIR . '/languages/' );

	/** Check for activated Genesis Framework (= template/parent theme) */
	if ( basename( get_template_directory() ) != 'genesis' ) {

		/** If no Genesis, deactivate ourself */
		deactivate_plugins( plugin_basename( __FILE__ ) );

		/** Deactivation message */
		wp_die( sprintf( __( 'Sorry, you can&rsquo;t activate unless you have installed the %1$sGenesis Framework%2$s', 'genesis-widgetized-footer' ), '<a href="http://deckerweb.de/go/genesis/" target="_new">', '</a>' ) );

	}  // end-if Genesis check

}  // end of function ddw_gwfoot_activation_check


add_action( 'init', 'ddw_gwfoot_setup' );
/**
 * Setup #1: Load all admin & frontend stuff, set helper constants.
 * Setup #2: Register Widget Areas (Note: Has to be early on the "init" hook in order to display translations!)
 *
 * @since 1.0
 * @version 1.3
 */
function ddw_gwfoot_setup() {

	/** Load the admin and frontend functions only when needed */
	if ( is_admin() ) {
		require_once( GWFOOT_PLUGIN_DIR . '/includes/gwfoot-admin.php' );
	} else {
		require_once( GWFOOT_PLUGIN_DIR . '/includes/gwfoot-frontend.php' );
	}

	/** Add "Widgets Page" link to plugin page */
	if ( is_admin() && current_user_can( 'edit_theme_options' ) ) {
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , 'ddw_gwfoot_widgets_page_link' );
	}

	/** Define helpfer constants and set defaults for removing certain functions/hooks */
	if ( ! defined( 'GWFOOT_REMOVE_LANDING_FOOTER' ) ) {
		define( 'GWFOOT_REMOVE_LANDING_FOOTER', TRUE );
	}

	if ( ! defined( 'GWFOOT_LANDING_DISCLAIMER' ) ) {
		define( 'GWFOOT_LANDING_DISCLAIMER', TRUE );
	}

	/** Check for activated Genesis Framework (= template/parent theme) */
	if ( basename( get_template_directory() ) == 'genesis' ) {

		/** Add shortcode support to widgets */
		add_filter( 'widget_text', 'do_shortcode' );

		/** Set filter for "Footer Area #1" widget title */
		$gwfoot_footer_one_widget_title = apply_filters( 'gwfoot_filter_footer_one_widget_title', __( 'Footer Area #1', 'genesis-widgetized-footer' ) );

		/** Set filter for "Footer Area #1" widget description */
		$gwfoot_footer_one_widget_description = apply_filters( 'gwfoot_filter_footer_one_widget_description', sprintf( __( 'This is the first widget area (%s) within the Genesis Footer.', 'genesis-widgetized-footer' ), $gwfoot_footer_one_widget_title ) );

		/** Register the "Footer Area #1" widget area */
		genesis_register_sidebar(
			array(
				'id' => 'gwfoot-footer-one-widget',
				'name' => esc_attr__( $gwfoot_footer_one_widget_title ),
				'description' => esc_attr__( $gwfoot_footer_one_widget_description ),
				'before_widget' => '<div id="%1$s" class="gwfoot-footer-one widget-area">',
				'after_widget' => '</div>',
			)
		);

		/** Set filter for "Footer Area #2" widget title */
		$gwfoot_footer_two_widget_title = apply_filters( 'gwfoot_filter_footer_two_widget_title', __( 'Footer Area #2', 'genesis-widgetized-footer' ) );

		/** Set filter for "Footer Area #2" widget description */
		$gwfoot_footer_two_widget_description = apply_filters( 'gwfoot_filter_footer_two_widget_description', sprintf( __( 'This is the second widget area (%s) within the Genesis Footer.', 'genesis-widgetized-footer' ), $gwfoot_footer_two_widget_title ) );

		/** Register the "Footer Area #2" widget area */
		genesis_register_sidebar(
			array(
				'id' => 'gwfoot-footer-two-widget',
				'name' => esc_attr__( $gwfoot_footer_two_widget_title ),
				'description' => esc_attr__( $gwfoot_footer_two_widget_description ),
				'before_widget' => '<div id="%1$s" class="gwfoot-footer-two widget-area">',
				'after_widget' => '</div>',
			)
		);

		/** Set filter for "Footer Disclaimer" widget title */
		$gwfoot_footer_disclaimer_widget_title = apply_filters( 'gwfoot_filter_footer_disclaimer_widget_title', __( 'Footer Disclaimer', 'genesis-widgetized-footer' ) );

		/** Set filter for "Footer Disclaimer" widget description */
		$gwfoot_footer_disclaimer_widget_description = apply_filters( 'gwfoot_filter_footer_disclaimer_widget_description', __( 'This is Footer Disclaimer widget area within the Genesis Footer.', 'genesis-widgetized-footer' ) );

		/**
		 * Register the "Footer Disclaimer" widget area
		 * Do not register for AgentPress 2.x and RealPro 1.x child themes
		 *  as these already have their own Disclaimer widget area
		 */
		if ( ! function_exists( 'agentpress_disclaimer' ) || ! function_exists( 'realpro_disclaimer' ) ) {
			genesis_register_sidebar(
				array(
					'id' => 'gwfoot-footer-disclaimer-widget',
					'name' => esc_attr__( $gwfoot_footer_disclaimer_widget_title ),
					'description' => esc_attr__( $gwfoot_footer_disclaimer_widget_description ),
					'before_widget' => '<div id="%1$s" class="gwfoot-footer-disclaimer widget-area">',
					'after_widget' => '</div>',
				)
			);
		} // end-if AgentPress 2.x / RealPro 1.x check

	}  // end-if Genesis check

}  // end of function ddw_gwfoot_setup


add_action( 'genesis_before', 'gwfoot_do_footer_widgets' );
/**
 * Add the new widgetized footer content sections
 *
 * @since 1.0
 *
 * @global mixed $gwfoot_footer_one_width, $gwfoot_footer_two_width
 */
function gwfoot_do_footer_widgets() {

	global $gwfoot_footer_one_width, $gwfoot_footer_two_width;

	$gwfoot_footer_one_width = 'default';
	$gwfoot_footer_two_width = 'default';

	/**
	 * Footer Areas widget logic
	 * 3 Cases: 'Footer Area #1' active, or 'Footer Area #2' active, or both.
	 *
	 * Dynamically set proper width.
	 * And respect different footer positions of Prose, Modern Blogger and Pretty Young Thing child themes.
	 */
	/** Case 1: only 'Footer Area #1' active */
	if ( is_active_sidebar( 'gwfoot-footer-one-widget' ) && ! is_active_sidebar( 'gwfoot-footer-two-widget' ) ) {

		$gwfoot_footer_one_width = 'full-width';

			// Check for Prose 1.0/1.5.x Child Theme (official)
		if ( defined( 'PROSE_SETTINGS_FIELD' ) ) {

			remove_action( 'genesis_after', 'genesis_do_footer' );
			add_action( 'genesis_after', 'gwfoot_display_footer_one_section' );

			// Check for Modern Blogger 1.0 Child Theme (market/community)
		} elseif ( function_exists( 'child_do_footer' ) ) {

			remove_action( 'genesis_footer', 'child_do_footer' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );

			// Check for Pretty Young Thing 1.1 Child Theme (official)
		} elseif ( function_exists( 'pretty_footer_top' ) ) {

			remove_action( 'genesis_footer', 'genesis_do_footer' );
			remove_action( 'genesis_after_footer', 'pretty_footer_top' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );

			// Check for Pretty Young Thing 1.0 Child Theme (official)
		} elseif ( function_exists( 'pretty_do_footer' ) || function_exists( 'pretty_do_footer_top' ) ) {

			remove_action( 'genesis_footer', 'pretty_do_footer' );
			remove_action( 'genesis_after_footer', 'pretty_do_footer_top' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );

			// Default Genesis Footer Hook position
		} else {

			remove_action( 'genesis_footer', 'genesis_do_footer' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );

		}  // end-if child theme check case 1

	/** Case 2: only 'Footer Area #2' active */
	} elseif ( is_active_sidebar( 'gwfoot-footer-two-widget' ) && ! is_active_sidebar( 'gwfoot-footer-one-widget' ) ) {

		$gwfoot_footer_two_width = 'full-width';

			// Check for Prose 1.0/1.5.x Child Theme (official)
		if ( defined( 'PROSE_SETTINGS_FIELD' ) ) {

			remove_action( 'genesis_after', 'genesis_do_footer' );
			add_action( 'genesis_after', 'gwfoot_display_footer_two_section' );

			// Check for Modern Blogger 1.0 Child Theme (market/community)
		} elseif ( function_exists( 'child_do_footer' ) ) {

			remove_action( 'genesis_footer', 'child_do_footer' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

			// Check for Pretty Young Thing 1.1 Child Theme (official)
		} elseif ( function_exists( 'pretty_footer_top' ) ) {

			remove_action( 'genesis_footer', 'genesis_do_footer' );
			remove_action( 'genesis_after_footer', 'pretty_footer_top' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

			// Check for Pretty Young Thing 1.0 Child Theme (official)
		} elseif ( function_exists( 'pretty_do_footer' ) || function_exists( 'pretty_do_footer_top' ) ) {

			remove_action( 'genesis_footer', 'pretty_do_footer' );
			remove_action( 'genesis_after_footer', 'pretty_do_footer_top' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

			// Default Genesis Footer Hook position
		} else {

			remove_action( 'genesis_footer', 'genesis_do_footer' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

		}  // end-if child theme check case 2

	/** Case 3: Both, 'Footer Area #1' AND 'Footer Area #2' active */
	} elseif ( is_active_sidebar( 'gwfoot-footer-one-widget' ) && is_active_sidebar( 'gwfoot-footer-two-widget' ) ) {

		$gwfoot_footer_one_width = 'one-third';
		$gwfoot_footer_two_width = 'two-thirds';

			// Check for Prose 1.0/1.5.x Child Theme (official)
		if ( defined( 'PROSE_SETTINGS_FIELD' ) ) {

			remove_action( 'genesis_after', 'genesis_do_footer' );
			add_action( 'genesis_after', 'gwfoot_display_footer_one_section' );
			add_action( 'genesis_after', 'gwfoot_display_footer_two_section' );

			// Check for Modern Blogger 1.0 Child Theme (market/community)
		} elseif ( function_exists( 'child_do_footer' ) ) {

			remove_action( 'genesis_footer', 'child_do_footer' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

			// Check for Pretty Young Thing 1.1 Child Theme (official)
		} elseif ( function_exists( 'pretty_footer_top' ) ) {

			remove_action( 'genesis_footer', 'genesis_do_footer' );
			remove_action( 'genesis_after_footer', 'pretty_footer_top' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

			// Check for Pretty Young Thing 1.0 Child Theme (official)
		} elseif ( function_exists( 'pretty_do_footer' ) || function_exists( 'pretty_do_footer_top' ) ) {

			remove_action( 'genesis_footer', 'pretty_do_footer' );
			remove_action( 'genesis_after_footer', 'pretty_do_footer_top' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

			// Default Genesis Footer Hook position
		} else {

			remove_action( 'genesis_footer', 'genesis_do_footer' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );
			add_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

		}  // end-if child theme check case 3

	}  // end-if widget case check

	/**
	 * Footer Disclaimer widget logic
	 *
	 * For Prose 1.0/1.5.x Child Theme using 'genesis_after' hook.
	 * Otherwise place in 'genesis_footer' hook, with lower priority.
	 */
	if ( is_active_sidebar( 'gwfoot-footer-disclaimer-widget' ) && GWFOOT_LANDING_DISCLAIMER ) {

			// Check for Prose 1.0/1.5.x Child Theme (official)
		if ( defined( 'PROSE_SETTINGS_FIELD' ) ) {

			add_action( 'genesis_after', 'gwfoot_display_footer_disclaimer_section', 15 );

			// Default Genesis Footer Hook position
		} else {

			add_action( 'genesis_footer', 'gwfoot_display_footer_disclaimer_section', 15 );

		}  // end-if child theme check

	}  // end-if widget check

}  // end of function gwfoot_do_footer_widgets


/**
 * Display the "Footer Area #1" section
 *
 * @since 1.0
 *
 * @global mixed $gwfoot_footer_one_width
 */
function gwfoot_display_footer_one_section() {

	global $gwfoot_footer_one_width;

	echo '<div id="gwfoot-footer-one-area" class="gwfoot-footer-one-' . $gwfoot_footer_one_width . '">';
	dynamic_sidebar( 'gwfoot-footer-one-widget' );
	echo '</div><!-- end #gwfoot-footer-one-area -->';

}  // end of function gwfoot_display_footer_one_section


/**
 * Display the "Footer Area #2" section
 *
 * @since 1.0
 *
 * @global mixed $gwfoot_footer_two_width
 */
function gwfoot_display_footer_two_section() {

	global $gwfoot_footer_two_width;

	echo '<div id="gwfoot-footer-two-area" class="gwfoot-footer-two-' . $gwfoot_footer_two_width . '">';
	dynamic_sidebar( 'gwfoot-footer-two-widget' );
	echo '</div><!-- end #gwfoot-footer-two-area -->';

}  // end of function gwfoot_display_footer_two_section


/**
 * Display the "Footer Disclaimer" section
 *
 * @since 1.0
 */
function gwfoot_display_footer_disclaimer_section() {

	echo '<div id="gwfoot-footer-disclaimer-area">';
	echo '<div class="gwfoot-footer-disclaimer-content">';
	dynamic_sidebar( 'gwfoot-footer-disclaimer-widget' );
	echo '</div><!-- end .gwfoot-footer-disclaimer-content -->';
	echo '</div><!-- end #gwfoot-footer-disclaimer-area -->';

}  // end of function gwfoot_display_footer_disclaimer_section


add_action( 'wp_enqueue_scripts', 'ddw_gwfoot_styles' );
/**
 * Enqueue a few additional CSS rules to hold the widgetized footer - only if widgets are active
 * plus for enhanced compatibility with Genesis Child Themes
 * 
 * @since 1.0
 * @version 1.1
 */
function ddw_gwfoot_styles() {

	/** Check for the active widget areas */
	if ( is_active_sidebar( 'gwfoot-footer-one-widget' ) || is_active_sidebar( 'gwfoot-footer-two-widget' ) || is_active_sidebar( 'gwfoot-footer-disclaimer-widget' ) ) {

		/** Enqueue our styles */
		wp_enqueue_style( 'genesis-widgetized-footer', plugins_url( 'css/gwfoot-styles.css', __FILE__ ), false, GWFOOT_VERSION, 'all' );

		/** Action hook: 'gwfoot_load_styles' - allows for enqueueing additional custom styles */
		do_action( 'gwfoot_load_styles' );

	}  // end-if active widgets check

}  // end of function ddw_gwfoot_styles


/**
 * Helper function for placing the Disclaimer widget at the very bottom
 *
 * This helper function fires through hook 'genesis_before' which provides the best priority for us.
 * Widget & markup then placed in hook: 'genesis_after'
 *
 * Usage: add_action( 'genesis_before', '__gwfoot_footer_disclaimer_bottom' );
 *
 * @since 1.0
 */
function __gwfoot_footer_disclaimer_bottom() {

	/** Check against Prose 1.0/1.5.x Child Theme (official) */
	if ( ! defined( 'PROSE_SETTINGS_FIELD' ) ) {

		remove_action( 'genesis_footer', 'gwfoot_display_footer_disclaimer_section', 15 );
		add_action( 'genesis_after', 'gwfoot_display_footer_disclaimer_section' );

	} // end-if child theme check

}  // end of function __gwfoot_footer_disclaimer_bottom
